# HostPermissionsAllowedList

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**methods** | **list[str]** |  | [optional] 
**paths** | **list[str]** |  | [optional] 
**query_parameters** | [**list[HostPermissionsQueryParameters]**](HostPermissionsQueryParameters.md) | A set of constraints on the parameters contained in the query string. | [optional] 
**body** | [**RuleBody**](RuleBody.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


